@@ -1,10 +1,10 @@
 /*
     avicore
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "aviclip.h"
 #include "misc/pixbuf.h"
@@ -42,12 +41,6 @@ enum
 #endif /* not G_OS_WIN32 */
 
 
-static void avi_clip_class_init (AviClipClass *klass);
-static void avi_clip_init       (AviClip      *clip);
-static void avi_clip_dispose    (GObject      *object);
-
-
-static GObjectClass *parent_class = NULL;
 static gint avi_clip_signals[LAST_SIGNAL] = {0};
 #ifdef G_OS_WIN32
 static UINT uFormat;            /* ja:クリップボード */
@@ -59,31 +52,8 @@ static GdkAtom atom_scenario;   /* ja:シナリオオブジェクト */
 /******************************************************************************
 *                                                                             *
 ******************************************************************************/
-GType
-avi_clip_get_type (void)
-{
-  static GType type = 0;
-
-  if (!type)
-    {
-      const static GTypeInfo info =
-      {
-        sizeof (AviClipClass),
-        NULL,               /* base_init */
-        NULL,               /* base_finalize */
-        (GClassInitFunc)avi_clip_class_init,
-        NULL,               /* class_finalize */
-        NULL,               /* class_data */
-        sizeof (AviClip),
-        0,                  /* n_preallocs */
-        (GInstanceInitFunc)avi_clip_init,
-      };
-
-      type = g_type_register_static (G_TYPE_OBJECT, "AviClip", &info, 0);
-    }
-
-  return type;
-}
+G_DEFINE_TYPE (AviClip, avi_clip, G_TYPE_OBJECT);
+static void avi_clip_dispose (GObject *object);
 
 
 static void
@@ -91,9 +61,7 @@ avi_clip_class_init (AviClipClass *klass)
 {
   GObjectClass *object_class;
 
-  parent_class = g_type_class_peek_parent (klass);
-  object_class = (GObjectClass *)klass;
-
+  object_class = G_OBJECT_CLASS (klass);
   object_class->dispose = avi_clip_dispose;
 
   klass->paste = NULL;
@@ -132,13 +100,14 @@ avi_clip_init (AviClip *clip)
 static void
 avi_clip_dispose (GObject *object)
 {
-  AviClip *clip = AVI_CLIP (object);
+  AviClip *clip;
 
+  clip = AVI_CLIP (object);
   if (clip->handler_destroy)
     g_signal_handler_disconnect (G_OBJECT (clip->window),
                                                         clip->handler_destroy);
-  if (G_OBJECT_CLASS (parent_class)->dispose)
-    G_OBJECT_CLASS (parent_class)->dispose (object);
+  if (G_OBJECT_CLASS (avi_clip_parent_class)->dispose)
+    G_OBJECT_CLASS (avi_clip_parent_class)->dispose (object);
 }
 
 
