@@ -1,10 +1,10 @@
 /*
     avicore
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,52 +13,19 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "avibase.h"
 #include "aviextra.h"
 
 
-static void avi_extra_class_init (AviExtraClass *klass);
-static void avi_extra_init       (AviExtra      *extra);
-#if GTK_CHECK_VERSION(2,2,0)
-static void avi_extra_dispose    (GObject       *object);
-#endif /* GTK_CHECK_VERSION(2,2,0) */
-
-
-static GtkVBoxClass *parent_class = NULL;
-
-
 /******************************************************************************
 *                                                                             *
 ******************************************************************************/
-GtkType
-avi_extra_get_type (void)
-{
-  static GType extra_type = 0;
-
-  if (!extra_type)
-    {
-      const static GTypeInfo extra_info =
-      {
-        sizeof (AviExtraClass),
-        NULL,               /* base_init */
-        NULL,               /* base_finalize */
-        (GClassInitFunc)avi_extra_class_init,
-        NULL,               /* class_finalize */
-        NULL,               /* class_data */
-        sizeof (AviExtra),
-        0,                  /* n_preallocs */
-        (GInstanceInitFunc)avi_extra_init,
-      };
-
-      extra_type = g_type_register_static (GTK_TYPE_VBOX, "AviExtra",
-                                                            &extra_info, 0);
-    }
-
-  return extra_type;
-}
+G_DEFINE_TYPE (AviExtra, avi_extra, GTK_TYPE_VBOX);
+#if GTK_CHECK_VERSION(2,2,0)
+static void avi_extra_dispose (GObject *object);
+#endif /* GTK_CHECK_VERSION(2,2,0) */
 
 
 static void
@@ -67,11 +34,7 @@ avi_extra_class_init (AviExtraClass *klass)
 #if GTK_CHECK_VERSION(2,2,0)
   GObjectClass *object_class;
 
-  object_class = (GObjectClass *)klass;
-#endif /* GTK_CHECK_VERSION(2,2,0) */
-
-  parent_class = g_type_class_peek_parent (klass);
-#if GTK_CHECK_VERSION(2,2,0)
+  object_class = G_OBJECT_CLASS (klass);
   object_class->dispose = avi_extra_dispose;
 #endif /* GTK_CHECK_VERSION(2,2,0) */
 }
@@ -125,8 +88,9 @@ avi_extra_init (AviExtra *extra)
 static void
 avi_extra_dispose (GObject *object)
 {
-  AviExtra *extra = AVI_EXTRA (object);
+  AviExtra *extra;
 
+  extra = AVI_EXTRA (object);
   if (extra->hbox_ico)
     gtk_widget_destroy (extra->hbox_ico);
   if (extra->hbox_jpeg)
@@ -134,8 +98,8 @@ avi_extra_dispose (GObject *object)
   if (extra->hbox_png)
     gtk_widget_destroy (extra->hbox_png);
 
-  if (G_OBJECT_CLASS (parent_class)->dispose)
-    G_OBJECT_CLASS (parent_class)->dispose (object);
+  if (G_OBJECT_CLASS (avi_extra_parent_class)->dispose)
+    G_OBJECT_CLASS (avi_extra_parent_class)->dispose (object);
 }
 #endif /* GTK_CHECK_VERSION(2,2,0) */
 
