@@ -1,10 +1,10 @@
 /*
     avicore
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #ifndef __AVI_EXTRA_H__
 #define __AVI_EXTRA_H__
@@ -23,9 +22,7 @@
 #include "avicore.h"
 
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 
 #define AVI_TYPE_EXTRA            (avi_extra_get_type ())
@@ -143,9 +140,7 @@ avi_extra_set_range (AviExtra   *extra,
                      const gint  end);
 
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 
 #endif /* __AVI_EXTRA_H__ */
