@@ -1,10 +1,10 @@
 /*
     Video maid
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,17 +13,18 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "general.h"
 #if GTK_CHECK_VERSION(2,8,0)
 # include "icons.h"
 #endif /* GTK_CHECK_VERSION(2,8,0) */
+#include "menu.h"
 #include "sigfile.h"
 #include "sigmain.h"
 #include "thread.h"
 #include "misc/fileio.h"
+#include "misc/misc.h"
 #include "orz/orzhistory.h"
 #include "orz/orzmdi.h"
 #include <time.h>
