@@ -1,10 +1,10 @@
 /*
     Video maid
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,14 +13,14 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "icons.h"
 #include "version.h"
 #include "avicore/acm.h"
 #include "avicore/icm.h"
 #include "misc/gnugpl.h"
+#include "misc/misc.h"
 
 
 /******************************************************************************
@@ -138,6 +138,7 @@ version_dialog (void)
 " ryoma <ryoma@users.sourceforge.jp>\n"
 "\n"
 "Icons Author:\n"
+" EIJI Shibuya\n"
 " from GTK+ Stock Icons\n"
 "\n"
 "Packager:\n"
