@@ -362,10 +362,12 @@ w32page_realize (GtkWidget *widget,
 {
   W32LdrPageData *pd;
 
+  g_signal_handlers_disconnect_by_func (G_OBJECT (widget),
+                                                w32page_realize, user_data);
   pd = g_object_get_data (G_OBJECT (widget), "user_data");
-  if (pd->lppspa)
+  if (pd->lppspa && pd->lppspa->pfnCallback)
     pd->lppspa->pfnCallback (widget, PSPCB_CREATE, pd->lppspa);
-  if (pd->lppspw)
+  if (pd->lppspw && pd->lppspw->pfnCallback)
     pd->lppspw->pfnCallback (widget, PSPCB_CREATE, pd->lppspw);
 }
 
@@ -380,12 +382,18 @@ w32page_destroy (GtkWidget *widget,
   pd = g_object_get_data (G_OBJECT (widget), "user_data");
   if (pd->lppspa)
     {
-      pd->lppspa->pfnCallback (widget, PSPCB_RELEASE, pd->lppspa);
+      if (pd->lppspa->pfnCallback)
+        pd->lppspa->pfnCallback (widget, PSPCB_RELEASE, pd->lppspa);
+      g_free ((gpointer)pd->lppspa->pResource);
+      g_free ((gpointer)pd->lppspa->pszTitle);
       g_free (pd->lppspa);
     }
   if (pd->lppspw)
     {
-      pd->lppspw->pfnCallback (widget, PSPCB_RELEASE, pd->lppspw);
+      if (pd->lppspw->pfnCallback)
+        pd->lppspw->pfnCallback (widget, PSPCB_RELEASE, pd->lppspw);
+      g_free ((gpointer)pd->lppspw->pResource);
+      g_free ((gpointer)pd->lppspw->pszTitle);
       g_free (pd->lppspw);
     }
   g_free (pd->title);
@@ -438,13 +446,13 @@ HPROPSHEETPAGE WINAPI CreatePropertySheetPageA (LPCPROPSHEETPAGEA lppsp)
                 && ((LPCDLGTEMPLATEEX)lppspa->pResource)->signature == 0xffff)
     {
       ((LPDLGTEMPLATEEX)lppspa->pResource)->style
-                                &= ~(WS_OVERLAPPED | WS_POPUP | WS_VISIBLE);
+                                &= ~(WS_OVERLAPPED | WS_POPUP | WS_DISABLED);
       ((LPDLGTEMPLATEEX)lppspa->pResource)->style |= WS_CHILD | WS_DLGFRAME;
     }
   else
     {
       ((LPDLGTEMPLATE)lppspa->pResource)->style
-                                &= ~(WS_OVERLAPPED | WS_POPUP | WS_VISIBLE);
+                                &= ~(WS_OVERLAPPED | WS_POPUP | WS_DISABLED);
       ((LPDLGTEMPLATE)lppspa->pResource)->style |= WS_CHILD | WS_DLGFRAME;
     }
   lppspa->hIcon = NULL;
@@ -492,6 +500,12 @@ HPROPSHEETPAGE WINAPI CreatePropertySheetPageA (LPCPROPSHEETPAGEA lppsp)
       g_signal_connect (G_OBJECT (hDlg), "destroy",
                                         G_CALLBACK (w32page_destroy), NULL);
     }
+  else
+    {
+      g_free ((gpointer)lppspa->pResource);
+      g_free ((gpointer)lppspa->pszTitle);
+      g_free (lppspa);
+    }
   return hDlg;
 }
 
@@ -538,13 +552,13 @@ HPROPSHEETPAGE WINAPI CreatePropertySheetPageW (LPCPROPSHEETPAGEW lppsp)
                 && ((LPCDLGTEMPLATEEX)lppspw->pResource)->signature == 0xffff)
     {
       ((LPDLGTEMPLATEEX)lppspw->pResource)->style
-                                &= ~(WS_OVERLAPPED | WS_POPUP | WS_VISIBLE);
+                                &= ~(WS_OVERLAPPED | WS_POPUP | WS_DISABLED);
       ((LPDLGTEMPLATEEX)lppspw->pResource)->style |= WS_CHILD | WS_DLGFRAME;
     }
   else
     {
       ((LPDLGTEMPLATE)lppspw->pResource)->style
-                                &= ~(WS_OVERLAPPED | WS_POPUP | WS_VISIBLE);
+                                &= ~(WS_OVERLAPPED | WS_POPUP | WS_DISABLED);
       ((LPDLGTEMPLATE)lppspw->pResource)->style |= WS_CHILD | WS_DLGFRAME;
     }
   lppspw->hIcon = NULL;
@@ -594,6 +608,12 @@ HPROPSHEETPAGE WINAPI CreatePropertySheetPageW (LPCPROPSHEETPAGEW lppsp)
       g_signal_connect (G_OBJECT (hDlg), "destroy",
                                         G_CALLBACK (w32page_destroy), NULL);
     }
+  else
+    {
+      g_free ((gpointer)lppspw->pResource);
+      g_free ((gpointer)lppspw->pszTitle);
+      g_free (lppspw);
+    }
   return hDlg;
 }
 
@@ -1176,6 +1196,8 @@ static void
 w32prsht_realize (GtkWidget            *widget,
                   PFNPROPSHEETCALLBACK  pfnCallback)
 {
+  g_signal_handlers_disconnect_by_func (G_OBJECT (widget),
+                                                w32prsht_realize, pfnCallback);
   pfnCallback (widget, PSCB_INITIALIZED, 0);
 }
 
@@ -1224,6 +1246,7 @@ INT WINAPI PropertySheetA (LPCPROPSHEETHEADERA lppsph)
     return GPOINTER_TO_INT (hWnd);
 
   gtk_dialog_run (GTK_DIALOG (hWnd));
+  gtk_widget_destroy (hWnd);
   for (i = 1; i == ID_PSRESTARTWINDOWS || i == ID_PSREBOOTSYSTEM; i++);
   return i;
 }
@@ -1269,6 +1292,7 @@ INT WINAPI PropertySheetW (LPCPROPSHEETHEADERW lppsph)
     return GPOINTER_TO_INT (hWnd);
 
   gtk_dialog_run (GTK_DIALOG (hWnd));
+  gtk_widget_destroy (hWnd);
   for (i = 1; i == ID_PSRESTARTWINDOWS || i == ID_PSREBOOTSYSTEM; i++);
   return i;
 }
