@@ -252,9 +252,11 @@ w32combo_DefWindowProc (HWND   hWnd,
           count = w32combo_DefWindowProc (hWnd, CB_GETCOUNT, 0, 0);
           position = wParam < 0 || count < wParam ? count : wParam;
           gtk_list_store_insert (store, &iter, position);
-          utf8str = wd->widechar
-            ? g_utf16_to_utf8 (GINT_TO_POINTER (lParam), -1, NULL, NULL, NULL)
-            : w32ldr_utf8_from_mb (GINT_TO_POINTER (lParam));
+          utf8str = lParam ? wd->widechar
+                           ? g_utf16_to_utf8 (GINT_TO_POINTER (lParam),
+                                                        -1, NULL, NULL, NULL)
+                           : w32ldr_utf8_from_mb (GINT_TO_POINTER (lParam))
+                           : g_strdup ("");
           gtk_list_store_set (store, &iter, 0, utf8str, 1, 0, -1);
           g_free (utf8str);
           return position;
@@ -265,9 +267,11 @@ w32combo_DefWindowProc (HWND   hWnd,
           gchar *utf8str;
           GtkWidget *list_item;
 
-          utf8str = wd->widechar
-            ? g_utf16_to_utf8 (GINT_TO_POINTER (lParam), -1, NULL, NULL, NULL)
-            : w32ldr_utf8_from_mb (GINT_TO_POINTER (lParam));
+          utf8str = lParam ? wd->widechar
+                           ? g_utf16_to_utf8 (GINT_TO_POINTER (lParam),
+                                                        -1, NULL, NULL, NULL)
+                           : w32ldr_utf8_from_mb (GINT_TO_POINTER (lParam))
+                           : g_strdup ("");
           list_item = gtk_list_item_new_with_label (utf8str);
           g_free (utf8str);
           gtk_widget_show (list_item);
@@ -298,9 +302,11 @@ w32combo_DefWindowProc (HWND   hWnd,
           gint i, length;
           GtkTreeModel *model;
 
-          utf8str = wd->widechar
-            ? g_utf16_to_utf8 (GINT_TO_POINTER (lParam), -1, NULL, NULL, NULL)
-            : w32ldr_utf8_from_mb (GINT_TO_POINTER (lParam));
+          utf8str = lParam ? wd->widechar
+                           ? g_utf16_to_utf8 (GINT_TO_POINTER (lParam),
+                                                        -1, NULL, NULL, NULL)
+                           : w32ldr_utf8_from_mb (GINT_TO_POINTER (lParam))
+                           : g_strdup ("");
           model = gtk_combo_box_get_model (GTK_COMBO_BOX (hWnd));
           length = gtk_tree_model_iter_n_children (model, NULL);
           for (i = wParam + 1; i < length; i++)
@@ -353,9 +359,11 @@ w32combo_DefWindowProc (HWND   hWnd,
           gint i, length;
           GList *glist;
 
-          utf8str = wd->widechar
-            ? g_utf16_to_utf8 (GINT_TO_POINTER (lParam), -1, NULL, NULL, NULL)
-            : w32ldr_utf8_from_mb (GINT_TO_POINTER (lParam));
+          utf8str = lParam ? wd->widechar
+                           ? g_utf16_to_utf8 (GINT_TO_POINTER (lParam),
+                                                        -1, NULL, NULL, NULL)
+                           : w32ldr_utf8_from_mb (GINT_TO_POINTER (lParam))
+                           : g_strdup ("");
           glist = gtk_container_get_children
                                     (GTK_CONTAINER (GTK_COMBO (hWnd)->list));
           length = g_list_length (glist);
@@ -482,9 +490,11 @@ w32combo_DefWindowProc (HWND   hWnd,
           gint i, length;
           GtkTreeModel *model;
 
-          utf8str = wd->widechar
-            ? g_utf16_to_utf8 (GINT_TO_POINTER (lParam), -1, NULL, NULL, NULL)
-            : w32ldr_utf8_from_mb (GINT_TO_POINTER (lParam));
+          utf8str = lParam ? wd->widechar
+                           ? g_utf16_to_utf8 (GINT_TO_POINTER (lParam),
+                                                        -1, NULL, NULL, NULL)
+                           : w32ldr_utf8_from_mb (GINT_TO_POINTER (lParam))
+                           : g_strdup ("");
           model = gtk_combo_box_get_model (GTK_COMBO_BOX (hWnd));
           length = gtk_tree_model_iter_n_children (model, NULL);
           for (i = wParam + 1; i < length; i++)
@@ -535,9 +545,11 @@ w32combo_DefWindowProc (HWND   hWnd,
           gint i, length;
           GList *glist;
 
-          utf8str = wd->widechar
-            ? g_utf16_to_utf8 (GINT_TO_POINTER (lParam), -1, NULL, NULL, NULL)
-            : w32ldr_utf8_from_mb (GINT_TO_POINTER (lParam));
+          utf8str = lParam ? wd->widechar
+                           ? g_utf16_to_utf8 (GINT_TO_POINTER (lParam),
+                                                        -1, NULL, NULL, NULL)
+                           : w32ldr_utf8_from_mb (GINT_TO_POINTER (lParam))
+                           : g_strdup ("");
           glist = gtk_container_get_children
                                     (GTK_CONTAINER (GTK_COMBO (hWnd)->list));
           length = g_list_length (glist);
@@ -659,10 +671,11 @@ w32combo_DefWindowProc (HWND   hWnd,
             gchar *utf8str;
             GtkWidget *entry;
 
-            utf8str = wd->widechar
-                            ? g_utf16_to_utf8 (GINT_TO_POINTER (lParam), -1,
-                                                            NULL, NULL, NULL)
-                            : w32ldr_utf8_from_mb (GINT_TO_POINTER (lParam));
+            utf8str = lParam ? wd->widechar
+                             ? g_utf16_to_utf8 (GINT_TO_POINTER (lParam),
+                                                        -1, NULL, NULL, NULL)
+                             : w32ldr_utf8_from_mb (GINT_TO_POINTER (lParam))
+                             : g_strdup ("");
 #if GTK_CHECK_VERSION(2,4,0)
             entry = gtk_bin_get_child (GTK_BIN (hWnd));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
@@ -783,7 +796,7 @@ w32ldr_control_create_combo (const gchar    *windowname,
   combo = (style & CBS_TYPEMASK) == CBS_DROPDOWNLIST
             ? gtk_combo_box_new_with_model (GTK_TREE_MODEL (store))
             : gtk_combo_box_entry_new_with_model (GTK_TREE_MODEL (store), 0);
-  g_object_unref (store);
+  g_object_unref (G_OBJECT (store));
   renderer = gtk_cell_renderer_text_new ();
   gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, TRUE);
   gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo),
