@@ -1,10 +1,10 @@
 /*
     w32loader
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #ifndef __W32TVIEW_H__
 #define __W32TVIEW_H__
@@ -23,6 +22,9 @@
 #include "user32.h"
 
 
+G_BEGIN_DECLS
+
+
 /* ja:ツリービュー */
 #define WC_TREEVIEWA "SysTreeView32"
 #define WC_TREEVIEWW (w32ldr_tchar_to_wc("SysTreeView32"))
@@ -380,4 +382,7 @@ typedef struct _TV_SORTCB
 #endif /* not UNICODE */
 
 
+G_END_DECLS
+
+
 #endif /* not __W32TVIEW_H__ */
